# _generated.ContinuousEvalsApi

All URIs are relative to *http://localhost*

Method | HTTP request | Description
------------- | ------------- | -------------
[**create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post**](ContinuousEvalsApi.md#create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post) | **POST** /api/v1/tasks/{task_id}/continuous_evals | Create a continuous eval
[**delete_continuous_eval_api_v1_continuous_evals_eval_id_delete**](ContinuousEvalsApi.md#delete_continuous_eval_api_v1_continuous_evals_eval_id_delete) | **DELETE** /api/v1/continuous_evals/{eval_id} | Delete a continuous eval
[**get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get**](ContinuousEvalsApi.md#get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get) | **GET** /api/v1/continuous_evals/{eval_id} | Get a continuous eval by id
[**list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get**](ContinuousEvalsApi.md#list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get) | **GET** /api/v1/tasks/{task_id}/continuous_evals/results | Get all continuous eval run results for a specific task
[**list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get**](ContinuousEvalsApi.md#list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get) | **GET** /api/v1/tasks/{task_id}/continuous_evals | Get all continuous evals for a specific task
[**rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post**](ContinuousEvalsApi.md#rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post) | **POST** /api/v1/continuous_evals/results/{run_id}/rerun | Rerun a failed continuous eval
[**update_continuous_eval_api_v1_continuous_evals_eval_id_patch**](ContinuousEvalsApi.md#update_continuous_eval_api_v1_continuous_evals_eval_id_patch) | **PATCH** /api/v1/continuous_evals/{eval_id} | Update a continuous eval


# **create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post**
> ContinuousEvalResponse create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post(task_id, continuous_eval_create_request)

Create a continuous eval

Create a continuous eval

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.continuous_eval_create_request import ContinuousEvalCreateRequest
from _generated.models.continuous_eval_response import ContinuousEvalResponse
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    task_id = 'task_id_example' # str | 
    continuous_eval_create_request = _generated.ContinuousEvalCreateRequest() # ContinuousEvalCreateRequest | 

    try:
        # Create a continuous eval
        api_response = api_instance.create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post(task_id, continuous_eval_create_request)
        print("The response of ContinuousEvalsApi->create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->create_continuous_eval_api_v1_tasks_task_id_continuous_evals_post: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **task_id** | **str**|  | 
 **continuous_eval_create_request** | [**ContinuousEvalCreateRequest**](ContinuousEvalCreateRequest.md)|  | 

### Return type

[**ContinuousEvalResponse**](ContinuousEvalResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **delete_continuous_eval_api_v1_continuous_evals_eval_id_delete**
> delete_continuous_eval_api_v1_continuous_evals_eval_id_delete(eval_id)

Delete a continuous eval

Delete a continuous eval

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    eval_id = 'eval_id_example' # str | The id of the continuous eval to delete.

    try:
        # Delete a continuous eval
        api_instance.delete_continuous_eval_api_v1_continuous_evals_eval_id_delete(eval_id)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->delete_continuous_eval_api_v1_continuous_evals_eval_id_delete: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **eval_id** | **str**| The id of the continuous eval to delete. | 

### Return type

void (empty response body)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**204** | Continuous eval deleted. |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get**
> ContinuousEvalResponse get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get(eval_id)

Get a continuous eval by id

Get a continuous eval by id

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.continuous_eval_response import ContinuousEvalResponse
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    eval_id = 'eval_id_example' # str | The id of the continuous eval to retrieve.

    try:
        # Get a continuous eval by id
        api_response = api_instance.get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get(eval_id)
        print("The response of ContinuousEvalsApi->get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->get_continuous_eval_by_id_api_v1_continuous_evals_eval_id_get: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **eval_id** | **str**| The id of the continuous eval to retrieve. | 

### Return type

[**ContinuousEvalResponse**](ContinuousEvalResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get**
> ListAgenticAnnotationsResponse list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get(task_id, sort=sort, page_size=page_size, page=page, id=id, continuous_eval_id=continuous_eval_id, trace_id=trace_id, annotation_score=annotation_score, run_status=run_status, created_after=created_after, created_before=created_before)

Get all continuous eval run results for a specific task

Get all continuous eval run results for a specific task

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.continuous_eval_run_status import ContinuousEvalRunStatus
from _generated.models.list_agentic_annotations_response import ListAgenticAnnotationsResponse
from _generated.models.pagination_sort_method import PaginationSortMethod
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    task_id = 'task_id_example' # str | 
    sort = _generated.PaginationSortMethod() # PaginationSortMethod | Sort the results (asc/desc) (optional)
    page_size = 10 # int | Page size. Default is 10. Must be greater than 0 and less than 5000. (optional) (default to 10)
    page = 0 # int | Page number (optional) (default to 0)
    id = 'id_example' # str | ID of the continuous eval to filter on. (optional)
    continuous_eval_id = 'continuous_eval_id_example' # str | ID of the continuous eval to filter on. (optional)
    trace_id = 'trace_id_example' # str | Trace ID to filter on. (optional)
    annotation_score = 56 # int | Annotation score to filter on. (optional)
    run_status = _generated.ContinuousEvalRunStatus() # ContinuousEvalRunStatus | Run status to filter on. (optional)
    created_after = 'created_after_example' # str | Inclusive start date for prompt creation in ISO8601 string format. Use local time (not UTC). (optional)
    created_before = 'created_before_example' # str | Exclusive end date for prompt creation in ISO8601 string format. Use local time (not UTC). (optional)

    try:
        # Get all continuous eval run results for a specific task
        api_response = api_instance.list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get(task_id, sort=sort, page_size=page_size, page=page, id=id, continuous_eval_id=continuous_eval_id, trace_id=trace_id, annotation_score=annotation_score, run_status=run_status, created_after=created_after, created_before=created_before)
        print("The response of ContinuousEvalsApi->list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->list_continuous_eval_run_results_api_v1_tasks_task_id_continuous_evals_results_get: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **task_id** | **str**|  | 
 **sort** | [**PaginationSortMethod**](.md)| Sort the results (asc/desc) | [optional] 
 **page_size** | **int**| Page size. Default is 10. Must be greater than 0 and less than 5000. | [optional] [default to 10]
 **page** | **int**| Page number | [optional] [default to 0]
 **id** | **str**| ID of the continuous eval to filter on. | [optional] 
 **continuous_eval_id** | **str**| ID of the continuous eval to filter on. | [optional] 
 **trace_id** | **str**| Trace ID to filter on. | [optional] 
 **annotation_score** | **int**| Annotation score to filter on. | [optional] 
 **run_status** | [**ContinuousEvalRunStatus**](.md)| Run status to filter on. | [optional] 
 **created_after** | **str**| Inclusive start date for prompt creation in ISO8601 string format. Use local time (not UTC). | [optional] 
 **created_before** | **str**| Exclusive end date for prompt creation in ISO8601 string format. Use local time (not UTC). | [optional] 

### Return type

[**ListAgenticAnnotationsResponse**](ListAgenticAnnotationsResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get**
> ListContinuousEvalsResponse list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get(task_id, sort=sort, page_size=page_size, page=page, name=name, llm_eval_name=llm_eval_name, created_after=created_after, created_before=created_before)

Get all continuous evals for a specific task

Get all continuous evals for a specific task

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.list_continuous_evals_response import ListContinuousEvalsResponse
from _generated.models.pagination_sort_method import PaginationSortMethod
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    task_id = 'task_id_example' # str | 
    sort = _generated.PaginationSortMethod() # PaginationSortMethod | Sort the results (asc/desc) (optional)
    page_size = 10 # int | Page size. Default is 10. Must be greater than 0 and less than 5000. (optional) (default to 10)
    page = 0 # int | Page number (optional) (default to 0)
    name = 'name_example' # str | Name of the continuous eval to filter on. (optional)
    llm_eval_name = 'llm_eval_name_example' # str | Name of the llm eval to filter on (optional)
    created_after = 'created_after_example' # str | Inclusive start date for prompt creation in ISO8601 string format. Use local time (not UTC). (optional)
    created_before = 'created_before_example' # str | Exclusive end date for prompt creation in ISO8601 string format. Use local time (not UTC). (optional)

    try:
        # Get all continuous evals for a specific task
        api_response = api_instance.list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get(task_id, sort=sort, page_size=page_size, page=page, name=name, llm_eval_name=llm_eval_name, created_after=created_after, created_before=created_before)
        print("The response of ContinuousEvalsApi->list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->list_continuous_evals_api_v1_tasks_task_id_continuous_evals_get: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **task_id** | **str**|  | 
 **sort** | [**PaginationSortMethod**](.md)| Sort the results (asc/desc) | [optional] 
 **page_size** | **int**| Page size. Default is 10. Must be greater than 0 and less than 5000. | [optional] [default to 10]
 **page** | **int**| Page number | [optional] [default to 0]
 **name** | **str**| Name of the continuous eval to filter on. | [optional] 
 **llm_eval_name** | **str**| Name of the llm eval to filter on | [optional] 
 **created_after** | **str**| Inclusive start date for prompt creation in ISO8601 string format. Use local time (not UTC). | [optional] 
 **created_before** | **str**| Exclusive end date for prompt creation in ISO8601 string format. Use local time (not UTC). | [optional] 

### Return type

[**ListContinuousEvalsResponse**](ListContinuousEvalsResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post**
> ContinuousEvalRerunResponse rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post(run_id)

Rerun a failed continuous eval

Rerun a failed continuous eval

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.continuous_eval_rerun_response import ContinuousEvalRerunResponse
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    run_id = 'run_id_example' # str | The id of the continuous eval run to rerun.

    try:
        # Rerun a failed continuous eval
        api_response = api_instance.rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post(run_id)
        print("The response of ContinuousEvalsApi->rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->rerun_continuous_eval_api_v1_continuous_evals_results_run_id_rerun_post: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **run_id** | **str**| The id of the continuous eval run to rerun. | 

### Return type

[**ContinuousEvalRerunResponse**](ContinuousEvalRerunResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

# **update_continuous_eval_api_v1_continuous_evals_eval_id_patch**
> ContinuousEvalResponse update_continuous_eval_api_v1_continuous_evals_eval_id_patch(eval_id, update_continuous_eval_request)

Update a continuous eval

Update a continuous eval

### Example

* Bearer Authentication (API Key):

```python
import _generated
from _generated.models.continuous_eval_response import ContinuousEvalResponse
from _generated.models.update_continuous_eval_request import UpdateContinuousEvalRequest
from _generated.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = _generated.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: API Key
configuration = _generated.Configuration(
    access_token = os.environ["BEARER_TOKEN"]
)

# Enter a context with an instance of the API client
with _generated.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = _generated.ContinuousEvalsApi(api_client)
    eval_id = 'eval_id_example' # str | The id of the continuous eval to update.
    update_continuous_eval_request = _generated.UpdateContinuousEvalRequest() # UpdateContinuousEvalRequest | 

    try:
        # Update a continuous eval
        api_response = api_instance.update_continuous_eval_api_v1_continuous_evals_eval_id_patch(eval_id, update_continuous_eval_request)
        print("The response of ContinuousEvalsApi->update_continuous_eval_api_v1_continuous_evals_eval_id_patch:\n")
        pprint(api_response)
    except Exception as e:
        print("Exception when calling ContinuousEvalsApi->update_continuous_eval_api_v1_continuous_evals_eval_id_patch: %s\n" % e)
```



### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **eval_id** | **str**| The id of the continuous eval to update. | 
 **update_continuous_eval_request** | [**UpdateContinuousEvalRequest**](UpdateContinuousEvalRequest.md)|  | 

### Return type

[**ContinuousEvalResponse**](ContinuousEvalResponse.md)

### Authorization

[API Key](../README.md#API Key)

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json

### HTTP response details

| Status code | Description | Response headers |
|-------------|-------------|------------------|
**200** | Successful Response |  -  |
**422** | Validation Error |  -  |

[[Back to top]](#) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to Model list]](../README.md#documentation-for-models) [[Back to README]](../README.md)

